==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebSnackbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebSnackbarDescription } from "./WebSnackbarDescription";
/**
 * @hidden
 */
var WebSnackbarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSnackbarDescriptionMetadata, _super);
    function WebSnackbarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSnackbarDescriptionMetadata.b = function (a) {
        if (WebSnackbarDescriptionMetadata.a == null) {
            WebSnackbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSnackbarDescriptionMetadata.c(WebSnackbarDescriptionMetadata.a);
        }
        if (a.k(WebSnackbarDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSnackbarDescriptionMetadata.a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebSnackbarDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Snackbar");
        a.item("__tagNameWC", "String:igc-snackbar");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Open", "Boolean");
        a.item("DisplayTime", "Number:double");
        a.item("KeepOpen", "Boolean");
        a.item("ActionText", "String");
        a.item("ActionRef", "EventRef::action");
    };
    WebSnackbarDescriptionMetadata.d = function (a) {
        WebSnackbarDescriptionMetadata.b(a);
        a.ac("WebSnackbar", function () { return new WebSnackbarDescription(); });
        a.ab("WebSnackbar", WebSnackbarDescriptionMetadata.a);
    };
    WebSnackbarDescriptionMetadata.$t = markType(WebSnackbarDescriptionMetadata, 'WebSnackbarDescriptionMetadata');
    WebSnackbarDescriptionMetadata.a = null;
    return WebSnackbarDescriptionMetadata;
}(Base));
export { WebSnackbarDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebSnackbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebBaseAlertLikeDescriptionMetadata } from "./WebBaseAlertLikeDescriptionMetadata";
import { WebSnackbarDescription } from "./WebSnackbarDescription";
/**
 * @hidden
 */
var WebSnackbarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSnackbarDescriptionMetadata, _super);
    function WebSnackbarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSnackbarDescriptionMetadata.b = function (a) {
        if (WebSnackbarDescriptionMetadata.a == null) {
            WebSnackbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSnackbarDescriptionMetadata.c(WebSnackbarDescriptionMetadata.a);
        }
        if (a.k(WebSnackbarDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebSnackbarDescriptionMetadata.a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebSnackbarDescriptionMetadata.c = function (a) {
        WebBaseAlertLikeDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Snackbar");
        a.item("__tagNameWC", "String:igc-snackbar");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("ActionText", "String");
        a.item("ActionRef", "EventRef::action");
    };
    WebSnackbarDescriptionMetadata.d = function (a) {
        WebSnackbarDescriptionMetadata.b(a);
        a.ae("WebSnackbar", function () { return new WebSnackbarDescription(); });
        a.ad("WebSnackbar", WebSnackbarDescriptionMetadata.a);
    };
    WebSnackbarDescriptionMetadata.$t = markType(WebSnackbarDescriptionMetadata, 'WebSnackbarDescriptionMetadata');
    WebSnackbarDescriptionMetadata.a = null;
    return WebSnackbarDescriptionMetadata;
}(Base));
export { WebSnackbarDescriptionMetadata };
